# The Summit Scheduler web application
# Copyright (C) 2008 - 2013 Ubuntu Community, Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


import datetime
from django import test as djangotest
from django.core.urlresolvers import reverse
from django.conf import settings

from model_mommy import mommy as factory
from summit.schedule.fields import NameField

from summit.schedule.models import (
    Summit,
    Slot,
    Meeting,
    Room,
    Agenda,
)

site_root = getattr(settings, 'SITE_ROOT', 'http://summit.ubuntu.com')

# Monkey-patch our NameField into the types of fields that the factory
# understands.  This is simpler than trying to subclass the Mommy
# class directly.
factory.default_mapping[NameField] = str


class MeetingPageTestCase(djangotest.TestCase):

    def test_meeting_page_url(self):
        """ Tests the creation and reverse lookup of meeting page urls"""
        now = datetime.datetime.utcnow()
        one_hour = datetime.timedelta(0, 3600)
        summit = factory.make_one(Summit, name='uds-test')
        summit.save()
        slot = factory.make_one(
            Slot,
            start_utc=now,
            end_utc=now+one_hour,
            type='open',
            summit=summit
        )
        slot.save()

        room = factory.make_one(Room, summit=summit)
        meeting = factory.make_one(
            Meeting,
            summit=summit,
            name='test-meeting',
            private=False
        )
        agenda = factory.make_one(
            Agenda,
            slot=slot,
            meeting=meeting,
            room=room
        )

        # check meeting page url generation
        self.assertEquals(
            meeting.meeting_page_url,
            '/uds-test/meeting/%s/test-meeting/' % meeting.id
        )

        # check meeting page url reverse lookup
        rev_args = ['uds-test', meeting.id, 'test-meeting']
        reverse_url = reverse('summit.schedule.views.meeting', args=rev_args)
        self.assertEquals(
            reverse_url,
            '/uds-test/meeting/%s/test-meeting/' % meeting.id
        )

        # check meeting details page
        response = self.client.get(reverse_url)
        self.assertEquals(response.status_code, 200)

        # check meeting in ical
        response = self.client.get('/uds-test.ical')
        self.assertEquals(response.status_code, 200)
        self.assertContains(
            response,
            'URL:%s/uds-test/meeting/%s/test-meeting/' % (
                site_root,
                meeting.id
            ),
            1
        )
